@@ -7,7 +7,7 @@
 #  define VTKIOPARALLELEXODUS_NO_EXPORT
 #else
 #  ifndef VTKIOPARALLELEXODUS_EXPORT
-#    ifdef vtkIOParallelExodus_EXPORTS
+#    ifdef IOParallelExodus_EXPORTS
         /* We are building this library */
 #      define VTKIOPARALLELEXODUS_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,26 +23,32 @@
 
 #ifndef VTKIOPARALLELEXODUS_DEPRECATED
 #  define VTKIOPARALLELEXODUS_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOPARALLELEXODUS_DEPRECATED_EXPORT VTKIOPARALLELEXODUS_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOPARALLELEXODUS_DEPRECATED_NO_EXPORT VTKIOPARALLELEXODUS_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOPARALLELEXODUS_NO_DEPRECATED
+#ifndef VTKIOPARALLELEXODUS_DEPRECATED_EXPORT
+#  define VTKIOPARALLELEXODUS_DEPRECATED_EXPORT VTKIOPARALLELEXODUS_EXPORT VTKIOPARALLELEXODUS_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkIOExodusModule.h"
+#ifndef VTKIOPARALLELEXODUS_DEPRECATED_NO_EXPORT
+#  define VTKIOPARALLELEXODUS_DEPRECATED_NO_EXPORT VTKIOPARALLELEXODUS_NO_EXPORT VTKIOPARALLELEXODUS_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOPARALLELEXODUS_NO_DEPRECATED
+#    define VTKIOPARALLELEXODUS_NO_DEPRECATED
+#  endif
+#endif
+/* AutoInit dependencies. */
 #include "vtkIOExodusModule.h"
 
-/* AutoInit implementations.  */
-#if defined(vtkIOParallelExodus_INCLUDE)
-# include vtkIOParallelExodus_INCLUDE
+
+/* AutoInit implementations. */
+#ifdef vtkIOParallelExodus_AUTOINIT_INCLUDE
+#include vtkIOParallelExodus_AUTOINIT_INCLUDE
 #endif
-#if defined(vtkIOParallelExodus_AUTOINIT)
-# include "vtkAutoInit.h"
-VTK_AUTOINIT(vtkIOParallelExodus)
+#ifdef vtkIOParallelExodus_AUTOINIT
+#include "vtkAutoInit.h"
+VTK_MODULE_AUTOINIT(vtkIOParallelExodus)
 #endif
 
-#endif
+#endif /* VTKIOPARALLELEXODUS_EXPORT_H */
